@@ -1,6 +1,6 @@
 /*
 ** freebsd4.c - Ident lookup routines for >= FreeBSD 4
-** Copyright (C) 2000-2003 Ryan McCabe <ryan@numb.org>
+** Copyright (C) 2000-2006 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -46,8 +46,18 @@
 #include <oidentd.h>
 #include <oidentd_util.h>
 #include <oidentd_inet_util.h>
+#include <oidentd_missing.h>
 #include <oidentd_options.h>
 
+/*
+** System dependant initialization. Call only once!
+** On failure, return false.
+*/
+
+bool core_init(void) {
+	return (true);
+}
+
 extern struct sockaddr_storage proxy;
 
 int get_user4(	in_port_t lport,
