@@ -1,6 +1,6 @@
 /*
 ** oidentd.c - oidentd ident (rfc1413) implementation.
-** Copyright (C) 1998-2003 Ryan McCabe <ryan@numb.org>
+** Copyright (C) 1998-2006 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -39,6 +39,7 @@
 
 #include <oidentd.h>
 #include <oidentd_util.h>
+#include <oidentd_missing.h>
 #include <oidentd_inet_util.h>
 #include <oidentd_user_db.h>
 #include <oidentd_options.h>
@@ -48,9 +49,9 @@
 #	include <udb.h>
 #endif
 
-static void sig_segv(int unused);
+static void sig_segv(int unused __notused) __noreturn;
 static void sig_child(int sig);
-static void sig_alarm(int unused);
+static void sig_alarm(int unused __notused) __noreturn;
 static void sig_hup(int unused);
 
 static void copy_pw(const struct passwd *pw, struct passwd *pwd);
@@ -87,6 +88,11 @@ int main(int argc, char **argv) {
 		exit(-1);
 	}
 
+	if (!core_init()) {
+		o_log(NORMAL, "Error initializing core");
+		exit(-1);
+	}
+
 	if (random_seed() != 0) {
 		o_log(NORMAL, "Error seeding random number generator");
 		exit(-1);
@@ -224,7 +230,9 @@ static int service_request(int insock, int outsock) {
 	laddr6 = laddr;
 	faddr6 = faddr;
 
-	if (laddr.ss_family == AF_INET6 && IN6_IS_ADDR_V4MAPPED(&SIN6(&laddr)->sin6_addr)) {
+	if (laddr.ss_family == AF_INET6 &&
+		IN6_IS_ADDR_V4MAPPED(&SIN6(&laddr)->sin6_addr))
+	{
 		struct in_addr in4;
 
 		sin_extractv4(&SIN6(&laddr)->sin6_addr, &in4);
@@ -255,7 +263,7 @@ static int service_request(int insock, int outsock) {
 	}
 
 	if (!VALID_PORT(lport_temp) || !VALID_PORT(fport_temp)) {
-		sockprintf(outsock, "%d , %d : ERROR : %s\r\n",
+		sockprintf(outsock, "%d,%d:ERROR:%s\r\n",
 				lport_temp, fport_temp, ERROR("INVALID-PORT"));
 
 		debug("[%s] %d , %d : ERROR : INVALID-PORT",
@@ -294,13 +302,13 @@ static int service_request(int insock, int outsock) {
 
 	if (con_uid == -1) {
 		if (failuser != NULL) {
-			sockprintf(outsock, "%d , %d : USERID : %s : %s\r\n",
+			sockprintf(outsock, "%d,%d:USERID:%s:%s\r\n",
 				lport, fport, ret_os, failuser);
 
 			o_log(NORMAL, "[%s] Failed lookup: %d , %d : (returned %s)",
 				host_buf, lport, fport, failuser);
 		} else {
-			sockprintf(outsock, "%d , %d : ERROR : %s\r\n",
+			sockprintf(outsock, "%d,%d:ERROR:%s\r\n",
 				lport, fport, ERROR("NO-USER"));
 
 			o_log(NORMAL, "[%s] %d , %d : ERROR : NO-USER",
@@ -312,7 +320,7 @@ static int service_request(int insock, int outsock) {
 
 	pw = getpwuid(con_uid);
 	if (pw == NULL) {
-		sockprintf(outsock, "%d , %d : ERROR : %s\r\n",
+		sockprintf(outsock, "%d,%d:ERROR:%s\r\n",
 			lport, fport, ERROR("NO-USER"));
 
 		debug("getpwuid(%d): %s", con_uid, strerror(errno));
@@ -322,7 +330,7 @@ static int service_request(int insock, int outsock) {
 
 	ret = get_ident(&pwd, lport, fport, &laddr, &faddr, suser, sizeof(suser));
 	if (ret == -1) {
-		sockprintf(outsock, "%d , %d : ERROR : %s\r\n",
+		sockprintf(outsock, "%d,%d:ERROR:%s\r\n",
 			lport, fport, ERROR("HIDDEN-USER"));
 
 		o_log(NORMAL, "[%s] %d , %d : HIDDEN-USER (%s)",
@@ -331,7 +339,7 @@ static int service_request(int insock, int outsock) {
 		goto out;
 	}
 
-	sockprintf(outsock, "%d , %d : USERID : %s : %s\r\n",
+	sockprintf(outsock, "%d,%d:USERID:%s:%s\r\n",
 		lport, fport, ret_os, suser);
 
 	o_log(NORMAL, "[%s] Successful lookup: %d , %d : %s (%s)",
@@ -367,7 +375,7 @@ static void free_pw(struct passwd *pw) {
 */
 
 static void sig_segv(int unused __notused) {
-	o_log(NORMAL, "Got SIGSEGV");
+	o_log(NORMAL, "Caught SIGSEGV");
 	exit(-1);
 }
 
@@ -388,7 +396,6 @@ static void sig_child(int sig) {
 
 static void sig_alarm(int unused __notused) {
 	o_log(NORMAL, "Timeout for request -- Closing connection");
-
 	exit(0);
 }
 
