@@ -1,6 +1,6 @@
 /*
 ** oidentd_masq.c - oidentd IP masquerading handler.
-** Copyright (C) 1998-2003 Ryan McCabe <ryan@numb.org>
+** Copyright (C) 1998-2006 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -39,6 +39,7 @@
 
 #include <oidentd.h>
 #include <oidentd_util.h>
+#include <oidentd_missing.h>
 #include <oidentd_inet_util.h>
 #include <oidentd_masq.h>
 #include <oidentd_options.h>
@@ -54,7 +55,7 @@ in_port_t fwdport;
 
 extern char *ret_os;
 
-static void fwd_alarm(int sig);
+static void fwd_alarm(int sig) __noreturn;
 static bool blank_line(const char *buf);
 
 /*
