@@ -1,6 +1,6 @@
 /*
 ** oidentd_util.c - oidentd utility functions.
-** Copyright (C) 2001-2003 Ryan McCabe <ryan@numb.org>
+** Copyright (C) 2001-2006 Ryan McCabe <ryan@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -43,6 +43,7 @@
 #include <oidentd.h>
 #include <oidentd_util.h>
 #include <oidentd_inet_util.h>
+#include <oidentd_missing.h>
 #include <oidentd_options.h>
 
 #ifdef HAVE_LIBUDB
@@ -399,8 +400,6 @@ void list_destroy(list_t *list, void (*free_data)(void *)) {
 ** Logging mechanism for oidentd.
 */
 
-#ifdef HAVE_VASPRINTF
-
 int o_log(int priority, const char *fmt, ...) {
 	va_list ap;
 	ssize_t ret;
@@ -425,33 +424,6 @@ int o_log(int priority, const char *fmt, ...) {
 	return (ret);
 }
 
-#else
-
-int o_log(int priority, const char *fmt, ...) {
-	va_list ap;
-	ssize_t ret;
-	char buf[4096];
-
-	if (opt_enabled(QUIET) && priority != LOG_CRIT)
-		return (0);
-
-	if (priority == DEBUG && !opt_enabled(DEBUG_MSGS))
-		return (0);
-
-	va_start(ap, fmt);
-	ret = vsnprintf(buf, sizeof(buf), fmt, ap);
-	va_end(ap);
-
-	if (isatty(fileno(stderr)))
-		fprintf(stderr, "%s\n", buf);
-	else
-		syslog(priority, "%s", buf);
-
-	return (ret);
-}
-
-#endif
-
 #ifdef HAVE_LIBUDB
 /*
 ** This function will look up the connection in the UDB shared memory tables.
